export default [
  require("/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/remark-admonitions/styles/infima.css"),
  require("/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/remark-admonitions/styles/infima.css"),
  require("/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/remark-admonitions/styles/infima.css"),
  require("/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/infima/dist/css/default/default.css"),
  require("/mnt/a32aae17-c247-4851-b81b-2ab2970c96e0/amalfi/soil-sdk/docs/website/node_modules/@docusaurus/theme-classic/lib/prism-include-languages"),
  require("../src/css/customTheme.css"),
];
